var __defProp = Object.defineProperty;
var __name = (target, value) => __defProp(target, "name", { value, configurable: true });

// src/index.ts
import { readFileSync, writeFileSync } from "fs";
import { join } from "path";

// src/utils/index.ts
var commentRegEx = new RegExp(/^#/);
var isComment = /* @__PURE__ */ __name((line) => commentRegEx.test(line), "isComment");
var startWithExport = /* @__PURE__ */ __name((line) => new RegExp(/^export/i).test(line), "startWithExport");
var isValidVariableName = /* @__PURE__ */ __name((variable) => new RegExp(/[a-zA-Z_]+[a-zA-Z0-9_]*/).test(variable), "isValidVariableName");

// src/index.ts
var loadEnvTypes = /* @__PURE__ */ __name((rootPath, options) => {
  if (!rootPath) {
    rootPath = process.cwd();
  }
  const fileName = (options == null ? void 0 : options.filename) ? options == null ? void 0 : options.filename : ".env";
  let envPath = join(rootPath, fileName);
  console.log(` *** loading environment variables from ${envPath}.`);
  let outputFileName = (options == null ? void 0 : options.outputPath) ? join(options == null ? void 0 : options.outputPath, "env.d.ts") : join(rootPath, "env.d.ts");
  const data = readFileSync(envPath, {
    encoding: "utf8"
  }).replace(/("""|''').*?\1/g, "").trim();
  let variables = [];
  for (const line of data.split(/\n/)) {
    if (!isComment(line)) {
      if (startWithExport(line)) {
        if (line.trim().length !== 0) {
          const _var = line.split(/=/)[0].trim().split(/\s/)[1];
          if (isValidVariableName(_var)) {
            variables.push(_var);
          } else {
            throw new Error(`There's an invalid variable name in your ${fileName} file.`);
          }
        }
      } else {
        if (line.indexOf("=") === -1 && line.trim().length !== 0) {
          throw new Error(`Invalid syntax in your ${fileName} file.`);
        } else {
          if (line.trim().length !== 0) {
            const _var = line.split(/=/)[0].trim();
            if (isValidVariableName(_var)) {
              variables.push(_var);
            } else {
              throw new Error(`There's an invalid variable name in your ${fileName} file.`);
            }
          }
        }
      }
    }
  }
  variables = variables.filter((v) => v.length >= 1);
  variables = [
    ...new Set(variables)
  ];
  const outPutText = `
  // types for your environmental variables
  declare namespace NodeJS {
    export interface ProcessEnv {
      ${variables.map((v, i) => {
    if (i === 0) {
      return v + " : string;\n";
    } else {
      return "			" + v + " : string;\n";
    }
  })}
    }
  }
  `.replace(/,/gim, "");
  writeFileSync(outputFileName, outPutText);
  console.log(`
 *** created env-types at ${outputFileName}.
`);
}, "loadEnvTypes");
var src_default = loadEnvTypes;
export {
  src_default as default
};
